@@ -167,9 +167,10 @@ plotnormals
 eulersolve
 '''
 
-paneller.Solid.__init__.__doc__='''__init__(sldlist=[], wraparounds=[]): instantiate solid, adding the first patches as their matrixes of point arrays are inserted in list sldlist, and their wrapping directions 
-are in the list of lists wraparounds. Ex. sldlist=[mat], wraparounds=[[1]] indicates a patch mat is to be first inserted, with the lines in the first row of mat
-being considered the same as those of the last row. wraparounds=[[0]] would do the same with first and last columns in \'mat\' matrix'''
+paneller.Solid.__init__.__doc__='''__init__(sldlist=[], wraparounds=[], full_parallel=False): instantiate solid, adding the first patches as their matrixes of point arrays are inserted in list sldlist, 
+and their wrapping directions are in the list of lists wraparounds. Ex. sldlist=[mat], wraparounds=[[1]] indicates a patch mat is to be first inserted, with the lines in the first row of mat
+being considered the same as those of the last row. wraparounds=[[0]] would do the same with first and last columns in \'mat\' matrix.
+If flag full_parallel is selected, parallel execution of aicm calculations will be held so as to stop recursive multiprocessing on windows. This is necessary when parallelizing the whole analysis operation'''
 paneller.Solid.addpatch.__doc__='''addpatch(sld, wraps=[], prevlines={}, invlats=[], tolerance=5e-5): add patch with point array matrix (list of lists) sld. prevlines indicates indexes of previously
 created lines to be used as edges for points in the first (key \'low\') or last (key \'up\') rows or columns (\'right\' and \'left\' keys).
 invlats contains the previously cited keys for laterals which should have its lines inverted when being added to panels. wraps contains wraparound commands as axis indexes, as described in reference
@@ -478,6 +479,8 @@ in wing\'s axis (if axis==2, note that alpha should be interpreted as a sideslip
 wing.wing_quadrant.hascorrection.__doc__='''hascorrection(): returns whether both wing quadrant sections have viscous corrections for application'''
 wing.wing_quadrant.calc_corrected_forces.__doc__='''calc_corrected_forces(): calculate corrections for sectional forces based on each edge section\'s available viscous corrections.
 Returns variations in coefficients return dCX, dCY, dCZ, dCl, dCm, dCn integrated along wing quadrant'''
+wing.wing_quadrant.design_derivs.__doc__='''design_derivs(sectside=1): returns derivatives in panel positions (drdi) and normal vectors (dndi) for an incidence variation 
+of section \'sectside\' in the given quadrant. Return value in degrees'''
 
 wing.wing.__doc__='''
 Class to model a whole wing through calls to methods of several queued wing quadrants
@@ -511,6 +514,7 @@ plot_input
 genwakepanels
 hascorrection
 calc_corrected_forces
+calc_design_dFM
 '''
 wing.wing.__init__.__doc__='''__init__(sld, wingquads=[]): instantiate wing with its list of wing quadrants (listed left/up to right/down) and its bound solid (sld)'''
 wing.wing.set_aircraft.__doc__='''set_aircraft(acft): sets the wing\'s bound aircraft to acft'''
@@ -530,6 +534,8 @@ wing.wing.genwakepanels.__doc__='''genwakepanels(offset=1000.0, a=0.0, b=0.0): g
 wing.wing.hascorrection.__doc__='''hascorrection(): checks whether all wing quadrants in the wing have been provided with viscous corrections. It is a condition for the application of those corrections
 in coefficient calculations'''
 wing.wing.calc_corrected_forces.__doc__='''calc_corrected_forces(): returns dCX, dCY, dCZ, dCl, dCm, dCn considering viscous corrections'''
+wing.wing.calc_design_dFM.__doc__='''calc_design_dFM(section=0, Uinf=1.0, rho=1.225, CG=np.zeros(3), M=0.0, gamma=1.4): calculates derivatives in forces and moments (returned respectively in tuple)
+according to variation in section (identified by section kwarg). Values in degrees'''
 
 body.__doc__='''
 Module containing definitions necessary for non-lifting body definitions
@@ -759,6 +765,7 @@ eulersolve
 forces_report
 plot_input
 plotgeometry
+design_derivatives
 '''
 aircraft.aircraft.__init__.__doc__='''__init__(sld, elems=[], Sref=0.0, cref=0.0, bref=0.0, echo=True, CG=np.array([0.0, 0.0, 0.0])): aircraft constructor, using bound Solid object as input, and all
 wings and bodies in elems list. Reference quantities, if provided as zero/not provided, will be calculated from the first input wing if any is present (or set to 1.0 if none is provided). If echo
@@ -804,6 +811,9 @@ are all accounted in radians. Returns external_history, alpha_history, beta_hist
 (in external coordinate system) in time (array time_history). beta history and alpha history are arrays reporting the evolution of alpha and beta perturbations in time, in radians. To add onboard moment addition
 for engines, use argument onboard. All coordinate systems (except for the one reported as external in return values) are stability coordinate systems (z, x axis inverted). If trim is set to True, 
 coefficients for analysis angle of attack and sideslip are set to zero to simulate a trimmed aircraft'''
+aircraft.aircraft.design_derivatives.__doc__='''design_derivatives(wings=[], echo=True): computes design derivatives of aerodynamic coefficients (in degrees) with respect to wing section incidence changes.
+returns list of lists. Each sublist includes the dictionaries, each dictionary with keys \'dCL\', \'dCD\', \'dCX\', etc for all derivatives of a given wing section. Order in return value is:
+[[w1-section1, w1-section2], [w2-section1, ...]]'''
 
 aerodynamic_output.__doc__='''
 Module containing functions for plotting aerodynamic results
@@ -906,12 +916,12 @@ dump
 create_functions
 __call__
 '''
-xfoil_visc.polar_correction.__init__.__doc__='''__init__(name='n4412', ext_append=True, aseq=[-10.0, 20.0, 2.0], Re_low=2e6, Re_high=3e6, Mach=0.03, flap=None, iter=300, cubic=True):
+xfoil_visc.polar_correction.__init__.__doc__='''__init__(name='n4412', ext_append=True, aseq=[-10.0, 20.0, 2.0], Re_low=2e6, Re_high=3e6, Mach=0.03, flap=None, iter=300, cubic=True, full_parallel=False):
 create polar correction for named airfoil, appending extension .dat for its file name if ext_append is True, between AOAs aseq[0] and aseq[1] with AOA step aseq[2]. Linear interpolation
 for Reynolds number extrapolation (check reference for xfoil_visc.polar_correction class for more info) is done between Reynolds numbers Re_low and Re_high. Mach number is set to kwarg
 Mach. Maximum iteration for viscous-inviscid coupling is set to kwarg iter. If cubic is True, polars will extrapolate data for AOAs using a cubic spline. A linear interpolation will be used
 otherwise. flap, if present, defines a length=3 list with, respectively, the x-axis chord percentage for the flap\'s axis, the thickness percentage for the
-given axis and its deflection in degrees.'''
+given axis and its deflection in degrees. A safety flag against Windows recursive multiprocess calls is set when full_parallel flag is triggered'''
 xfoil_visc.polar_correction.dump.__doc__='''dump(poldir='', polname='n4412', ext_append=True, echo=True): prints polar in .plr format (appending extension if ext_append is True) to file polname in directory
 poldir (or pwd if len(poldir)==0). Data is printed to stdio as dumped into file if echo is True'''
 xfoil_visc.polar_correction.create_functions.__doc__='''create_functions(cubic=True): creates cubic (or linear if cubic==False) interpolations for variables:
